from setuptools import setup

setup(
    name='iberzetsn',
    version='0.1.1',
    description='A library for Yiddish transliteration',
    url='https://github.com/jwg4/iberzetsn',
    author='Jack Grahl',
    author_email='jack.grahl@gmail.com',
    license='MIT',
    packages=["iberzetsn"],
    test_suite="tests"
)
